#[repr(C)]pub struct WireConfig {
pub protocol_major: Le16,
pub protocol_minor: Le16,
pub command_queue_count: Le16,
pub max_chain_descriptors: Le16,
pub max_request_bytes: Le32,
pub max_response_bytes: Le32,
}Fields
protocol_major: Le16protocol_minor: Le16command_queue_count: Le16max_chain_descriptors: Le16max_request_bytes: Le32max_response_bytes: Le32Implementations
Sourceimpl WireConfig
impl WireConfig
Sourcepub fn validate(&self) -> Result<(), ConfigError>
pub fn validate(&self) -> Result<(), ConfigError>
Validates that this configuration can provide the protocol 1.0 baseline.
A higher minor version is accepted and used with 1.0 behavior until separately negotiated extensions are understood.